@@ -3,9 +3,10 @@ from htmlentitydefs import name2codepoint
 from re import sub
 
 from django.core.paginator import Paginator, InvalidPage, EmptyPage
+from django.db.models.fields.related import ReverseSingleRelatedObjectDescriptor
 
 
-def decode_html_entities(html): 
+def decode_html_entities(html):
     """
     Remove HTML entities from a string.
     Adapted from http://effbot.org/zone/re-sub.htm#unescape-html
@@ -28,10 +29,11 @@ def decode_html_entities(html):
         return html
     return sub("&#?\w+;", decode, html.replace("&amp;", "&"))
 
+
 def is_editable(obj, request):
     """
-    Returns True if the object is editable for the request. First check for 
-    a custom ``editable`` handler on the object, otherwise use the logged 
+    Returns True if the object is editable for the request. First check for
+    a custom ``editable`` handler on the object, otherwise use the logged
     in user and check change permissions for the object's model.
     """
     if hasattr(obj, "is_editable"):
@@ -40,9 +42,10 @@ def is_editable(obj, request):
         perm = obj._meta.app_label + "." + obj._meta.get_change_permission()
         return request.user.is_authenticated() and request.user.has_perm(perm)
 
+
 def paginate(objects, page_num, per_page, max_paging_links):
     """
-    Return a paginated page for the given objects, giving it a custom 
+    Return a paginated page for the given objects, giving it a custom
     ``visible_page_range`` attribute calculated from ``max_paging_links``.
     """
     paginator = Paginator(list(objects), per_page)
@@ -56,9 +59,47 @@ def paginate(objects, page_num, per_page, max_paging_links):
         objects = paginator.page(paginator.num_pages)
     page_range = objects.paginator.page_range
     if len(page_range) > max_paging_links:
-        start = min(objects.paginator.num_pages - max_paging_links, 
+        start = min(objects.paginator.num_pages - max_paging_links,
             max(0, objects.number - (max_paging_links / 2) - 1))
         page_range = page_range[start:start + max_paging_links]
     objects.visible_page_range = page_range
     return objects
 
+
+def base_concrete_model(abstract, instance):
+    """
+    Used in methods of abstract models to find the super-most concrete
+    (non abstract) model in the inheritence chain that inherits from the
+    given abstract model. This is so the methods in the abstract model can
+    query data consistantly across the correct concrete model.
+
+    Consider the following::
+
+        class Abstract(models.Model)
+
+            class Meta:
+                abstract = True
+
+            def concrete(self):
+                return concrete_model_for(Abstract, self)
+
+        class Super(Abstract):
+            pass
+
+        class Sub(Super):
+            pass
+
+        sub = Sub.objects.create()
+        sub.real_obj() # returns Super
+
+    In actual Mezzanine usage, this allows methods in the ``Displayable`` and
+    ``Orderable`` abstract models to access the ``Page`` instance when
+    instances of custom content types, (eg: models that inherit from ``Page``)
+    need to query the ``Page`` model to determine correct values for ``slug``
+    and ``_order`` which are only relevant in the context of the ``Page``
+    model and not the model of the custom content type.
+    """
+    for cls in reversed(instance.__class__.__mro__):
+        if issubclass(cls, abstract) and not cls._meta.abstract:
+            return cls
+    return instance.__class__
